@@ -249,6 +249,27 @@ class LearningTree:
         i = self.m_deps[lesson_id].index(id_to_delete)
         del self.m_deps[lesson_id][i]
         self.sort_topics()
+    def iterate_all_lessons2(self):
+        """
+        Iterate all lessons that are added to the learning tree.
+        Yields the tuple (lesson_ids, path,)
+        """
+        def do_children(item, path):
+            # path == (0,) is the first menu on the menubar
+            path = path.child()
+            for c in item.children:
+                if isinstance(c, Menu):
+                    for x in do_children(c, path):
+                        yield x
+                else:
+                    assert isinstance(c, basestring)
+                    yield c, path
+                path = path.next()
+        path = Path((0,))
+        for menu in self.m_menus:
+            for x in do_children(menu, path):
+                yield x
+            path = path.next()
     def iterate_all_lessons(self):
         """
         Iterate all lessons that are added to the learning tree.
@@ -933,7 +954,16 @@ class Window(gtk.Window):
             self.m_tree.add_lesson(path, lesson_id)
             iter = self.m_model.get_iter(path)
             self.m_model.append(iter, (self.m_app.lessonfile_manager.get(lesson_id, 'title'), _("Lesson")))
+            self._recreate_tree(lesson_id)
         dlg.destroy()
+    def _recreate_tree(self, focus_id):
+        self.m_model.clear()
+        self.__create_model()
+        for lesson_id, path in self.m_tree.iterate_all_lessons2():
+            if lesson_id == focus_id:
+                break
+        self.g_treeview.expand_to_path(path)
+        self.g_treeview.set_cursor(path)
     def delete_menu(self, path):
         """
         FIXME Deleting a menu will not delete the dependencies between
@@ -1037,6 +1067,20 @@ class TestLearningTree(unittest.TestCase):
         tree.add_lesson((0, 0), "id3")
         v = list(tree.iterate_all_lessons())
         self.assertEqual(v, ['id1', 'id2', 'id3'])
+    def test_iterate_all_lessons2(self):
+        tree = LearningTree(None)
+        tree.new_menu("Menu 1")
+        tree.new_topic(0, "Submenu 0")
+        tree.add_lesson((0, 0), "id1")
+        tree.add_lesson((0, 0), "id2")
+        tree.add_lesson((0, 0), "id3")
+        tree.new_topic(0, "Submenu 1")
+        tree.add_lesson((0, 1), "id11")
+        tree.add_lesson((0, 1), "id12")
+        tree.add_lesson((0, 1), "id13")
+        v = list(tree.iterate_all_lessons2())
+        self.assertEqual(v, [('id1', (0, 0, 0)), ('id2', (0, 0, 1)), ('id3', (0, 0, 2)), ('id11', (0, 1, 0)), ('id12', (0, 1, 1)), ('id13', (0, 1, 2))])
+
 
 
 if __name__ == '__main__':
