@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 if __name__ == '__main__':
     import testsetup
@@ -229,7 +229,7 @@ class LessonfileCommon(object):
             self.header.random_transpose = ['key', -5, 5]
         # Backward compatability to handle old style
         # random_transpose = -4, 5 FIXMECOMPAT
-        if len(self.header.random_transpose) == 2:
+        if self.header.random_transpose and len(self.header.random_transpose) == 2:
             self.header.random_transpose \
                 = ['semitones'] + self.header.random_transpose
     def generate_test_questions(self):
