@@ -453,7 +453,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
     def display_exception_message(self, exception, err_file=None, msg=None):
         """Call this function only inside an except clause."""
         if err_file:
-            msg = _("Exception catched in %s:%i\n") % (err_file, sys.exc_info()[2].tb_lineno)
+            msg = _("Exception caught in %s:%i\n") % (err_file, sys.exc_info()[2].tb_lineno)
         elif not msg:
             msg = ""
         exception_str = unicode(exception)
